@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 """Unit test for trepan.lib.bytecode"""
 import inspect
-
-from xdis import IS_PYPY, PYTHON_VERSION_TRIPLE
+import platform
+import pytest
 
 from trepan.lib.bytecode import is_def_stmt, op_at_frame, stmt_contains_opcode
 
@@ -15,17 +15,11 @@ def test_contains_make_function():
     return
 
 
+@pytest.mark.skipif(platform.python_implementation() == "GraalVM",
+                    reason="op_at_frame() doesn't work for Graal (JVM) bytecode")
 def test_op_at_frame():
     frame = inspect.currentframe()
-    if IS_PYPY or PYTHON_VERSION_TRIPLE >= (3, 9):
-        if PYTHON_VERSION_TRIPLE >= (3, 11):
-            call_opcode = "CACHE"
-        elif PYTHON_VERSION_TRIPLE > (3, 9):
-            call_opcode = "CALL_FUNCTION"
-        else:
-            call_opcode = "CALL_METHOD"
-    else:
-        call_opcode = "CALL_FUNCTION"
+    call_opcode = "CALL"
 
     assert call_opcode == op_at_frame(frame)
     return
