@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-#  Copyright (C) 2009-2010, 2013, 2015, 2017-2018, 2020 Rocky Bernstein
+#  Copyright (C) 2009-2010, 2013, 2015, 2017-2018, 2020,
+#  2024 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 # Our local modules
 from trepan.processor.command.base_cmd import DebuggerCommand
 from trepan.lib.printing import printf
-from trepan.processor.complete import complete_identifier
+from trepan.processor.complete_rl import complete_identifier
 
 
 class PCommand(DebuggerCommand):
