@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#   Copyright (C) 2008-2010, 2012-2013, 2015, 2020, 2023 Rocky
+#   Copyright (C) 2008-2010, 2012-2013, 2015, 2020, 2023-2025 Rocky
 #   Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -15,6 +15,10 @@
 #
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+from abc import ABC
+from types import FrameType
+from typing import Optional
 from pygments.console import colorize
 
 NotImplementedMessage = "This method must be overridden in a subclass"
@@ -22,15 +26,17 @@ NotImplementedMessage = "This method must be overridden in a subclass"
 __all__ = ["Processor"]
 
 
-class Processor(object):
+class Processor(ABC):
     """A processor is the thing that handles the events that come to
     the debugger.  It has it's own I/O mechanism and a way to handle
     the events.
     """
 
-    def __init__(self, core_obj):
+    def __init__(self, core_obj, opts: Optional[dict]=None):
         self.core = core_obj
         self.debugger = core_obj.debugger
+        self.opts = opts
+        self.intf = []
         return
 
     # Note for errmsg, msg, and msg_nocr we don't want to simply make
@@ -54,7 +60,7 @@ class Processor(object):
         """Convenience short-hand for self.debugger.intf[-1].msg_nocr"""
         return self.intf[-1].msg_nocr(msg)
 
-    def event_processor(self, frame, event, arg):
+    def event_processor(self, frame: FrameType, event, event_arg):
         raise NotImplementedError(NotImplementedMessage)
 
     def rst_msg(self, text, opts={}):
@@ -75,6 +81,12 @@ class Processor(object):
         return self.msg(message, opts)
 
     def settings(self, setting):
-        return self.core.debugger.settings[setting]
+        return self.core.debugger.settings.get(setting)
 
+    def warnrmsg(self, message, opts={}):
+        """Convenience short-hand for self.intf[-1].warnmsg"""
+        if "plain" != self.debugger.settings["highlight"]:
+            message = colorize("standout", message)
+            pass
+        return self.intf[-1].warnmsg(message)
     pass
